#ifndef NT2_INCLUDE_FUNCTIONS_ACOSH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ACOSH_HPP_INCLUDED

#include <nt2/hyperbolic/include/functions/acosh.hpp>

#endif
